Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(372)

Unified Diff: webrtc/api/objc/RTCVideoSource.h

Issue 1546783002: Move RTCVideoSource to webrtc/api/objc. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@updateRTCMediaSource
Patch Set: Update against master Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/api/objc/RTCMediaSource+Private.h ('k') | webrtc/api/objc/RTCVideoSource.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/api/objc/RTCVideoSource.h
diff --git a/webrtc/api/objc/RTCMediaSource.h b/webrtc/api/objc/RTCVideoSource.h
similarity index 89%
rename from webrtc/api/objc/RTCMediaSource.h
rename to webrtc/api/objc/RTCVideoSource.h
index 0b36b8d7093543c803f6097d28488efef8678306..a98fa6c6bba626c52ea4331bb1b3d4d6bd0bd1a9 100644
--- a/webrtc/api/objc/RTCMediaSource.h
+++ b/webrtc/api/objc/RTCVideoSource.h
@@ -19,9 +19,9 @@ typedef NS_ENUM(NSInteger, RTCSourceState) {
NS_ASSUME_NONNULL_BEGIN
-@interface RTCMediaSource : NSObject
+@interface RTCVideoSource : NSObject
-/** The current state of the RTCMediaSource. */
+/** The current state of the RTCVideoSource. */
@property(nonatomic, readonly) RTCSourceState state;
- (instancetype)init NS_UNAVAILABLE;
« no previous file with comments | « webrtc/api/objc/RTCMediaSource+Private.h ('k') | webrtc/api/objc/RTCVideoSource.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698